OC.L10N.register(
    "logreader",
    {
    "Logging" : "Регистриране",
    "Log Reader" : "Четец на журнал",
    "A log reader for Nextcloud" : "Четец на журнал за Nextcloud",
    "Log reader for Nextcloud" : "Четец на журнал за Nextcloud",
    "Level" : "Ниво",
    "App" : "Приложение",
    "Time" : "Време",
    "Line {line}" : "Ред {line}",
    "Download logs" : "Изтегляне на журнали",
    "Ctrl" : "Ctrl /бутон/",
    "Application" : "Приложение",
    "Message" : "Съобщение",
    "Show details" : "Показване на подробности",
    "Debug" : "Отстраняване на грешки",
    "Info" : "Информация",
    "Warning" : "Внимание",
    "Error" : "Грешка",
    "Fatal" : "Фатална",
    "Error parsing log" : "Грешка при анализиране на журнал",
    "Caused by " : "Причинена от",
    "Copy" : "Копиране",
    "Copy raw" : "Копирайте необработено",
    "Copy formatted" : "Копирането е форматирано",
    "No server logs" : "Няма журнали на сървъра",
    "One or more entries are hidden by the log level filter" : "Един или повече записи са скрити от филтър на ниво журнал",
    "Everything is working fine" : "Всичко работи добре",
    "Load log file" : "Зареждане на регистрационен файл /журнал/",
    "Invalid log file" : "Невалиден регистрационен файл",
    "Log levels" : "Регистрационни нива",
    "Log content" : "Съдържание на журнал",
    "Live update" : "Обновяване на живо"
},
"nplurals=2; plural=(n != 1);");
